==> qtjambi-positioning-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiPositioning/QGeoSatelliteInfoSource_shell.h <==
#ifndef QGEOSATELLITEINFOSOURCE_SHELL_H
#define QGEOSATELLITEINFOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPositioning/qgeosatelliteinfosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPositioning/qgeosatelliteinfo.h>
#include <QtJambi/RegistryAPI>


class QGeoSatelliteInfoSource_shell : public QGeoSatelliteInfoSource, public QtJambiShellInterface
{
public:
    QGeoSatelliteInfoSource_shell(QObject* parent0);
    ~QGeoSatelliteInfoSource_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoSatelliteInfoSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int minimumUpdateInterval() const override;
    void requestUpdate(int timeout0) override;
    void setUpdateInterval(int msec0) override;
    void startUpdates() override;
    void stopUpdates() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGeoSatelliteInfoSource_access : public QGeoSatelliteInfoSource
{
    jint __qt_error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_minimumUpdateInterval(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_requestUpdate_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timeout0);
    void __qt_setUpdateInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msec0);
    void __qt_startUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stopUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QGEOSATELLITEINFOSOURCE_SHELL_H

==> qtjambi-positioning-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiPositioning/QGeoSatelliteInfoSource_shell.h <==
#ifndef QGEOSATELLITEINFOSOURCE_SHELL_H
#define QGEOSATELLITEINFOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPositioning/qgeosatelliteinfosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPositioning/qgeosatelliteinfo.h>
#include <QtJambi/RegistryAPI>


class QGeoSatelliteInfoSource_shell : public QGeoSatelliteInfoSource, public QtJambiShellInterface
{
public:
    QGeoSatelliteInfoSource_shell(QObject* parent0);
    ~QGeoSatelliteInfoSource_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoSatelliteInfoSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int minimumUpdateInterval() const override;
    void requestUpdate(int timeout0) override;
    void setUpdateInterval(int msec0) override;
    void startUpdates() override;
    void stopUpdates() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGeoSatelliteInfoSource_access : public QGeoSatelliteInfoSource
{
    jint __qt_error_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_minimumUpdateInterval_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_requestUpdate_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timeout0);
    void __qt_setUpdateInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msec0);
    void __qt_startUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stopUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QGEOSATELLITEINFOSOURCE_SHELL_H
